summaryrefslogtreecommitdiffstats
path: root/kinit/kinit.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:47:22 -0600
commit28edc0aa2ab09297288186f5bc15765eb7be58c0 (patch)
tree7b7a01768b3781763186c825af21bb14717d2c32 /kinit/kinit.cpp
parent07c48c43ff72c237e4028154f4594102b798073f (diff)
downloadtdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.tar.gz
tdelibs-28edc0aa2ab09297288186f5bc15765eb7be58c0.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kinit/kinit.cpp')
-rw-r--r--kinit/kinit.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kinit/kinit.cpp b/kinit/kinit.cpp
index 9bc6b7b1b..d7e7c7e1c 100644
--- a/kinit/kinit.cpp
+++ b/kinit/kinit.cpp
@@ -1759,8 +1759,8 @@ int main(int argc, char **argv, char **envp)
tdeinit_library_path();
// Don't make our instance the global instance
// (do it only after tdeinit_library_path, that one indirectly uses KConfig,
- // which seems to be buggy and always use KGlobal instead of the maching TDEInstance)
- KGlobal::_instance = 0L;
+ // which seems to be buggy and always use TDEGlobal instead of the maching TDEInstance)
+ TDEGlobal::_instance = 0L;
// don't change envvars before tdeinit_initsetproctitle()
unsetenv("LD_BIND_NOW");
unsetenv("DYLD_BIND_AT_LAUNCH");